==> Meta-0.06.tar.gz: Meta-0.06/Meta/Lang/Xml/xml_dom_print.pl <==
#!/usr/bin/env perl

use strict qw(vars refs subs);
use Meta::Utils::System qw();
use Meta::Utils::Opts::Opts qw();
use Meta::Baseline::Aegis qw();
use XML::DOM qw();
use HTML::TreeBuilder qw();
use HTML::DOMbo qw();

my($file,$html);
my($opts)=Meta::Utils::Opts::Opts->new();
$opts->set_standard();
$opts->def_devf("file","what input file to use ?","xmlx/connections/connections.xml",\$file);
$opts->def_bool("html","is the input html ?",0,\$html);
$opts->set_free_allo(0);
$opts->analyze(\@ARGV);

$file=Meta::Baseline::Aegis::which($file);
my($doc);
if($html) {
	my($tree)=HTML::TreeBuilder->new();
	$tree->ignore_ignorable_whitespace(0);
	$tree->no_space_compacting(1);
	$tree->parse_file($file);
	#this is possible because of HTML::DOMbo
	$doc=$tree->to_XML_DOM();
} else {
	my($parser)=XML::DOM::Parser->new();
	$doc=$parser->parsefile($file);
}
print $doc->toString();

Meta::Utils::System::exit(1);

__END__

=head1 NAME

xml_dom_print.pl - parse an XML using DOM and print the result.

=head1 COPYRIGHT

Copyright (C) 2001, 2002 Mark Veltzer;
All rights reserved.

=head1 LICENSE

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.

=head1 DETAILS

	MANIFEST: xml_dom_print.pl
	PROJECT: meta
	VERSION: 0.00

=head1 SYNOPSIS

	xml_dom_print.pl [options]

=head1 DESCRIPTION

This is a small program which reads an XML document, parses it using
XML::DOM and prints the result. You can use this software to verify
the correctness of an XML document or to see its structure more
clearly.

=head1 OPTIONS

=over 4

=item B<help> (type: bool, default: 0)

display help message

=item B<pod> (type: bool, default: 0)

display pod options snipplet

=item B<man> (type: bool, default: 0)

display manual page

=item B<quit> (type: bool, default: 0)

quit without doing anything

=item B<gtk> (type: bool, default: 0)

run a gtk ui to get the parameters

=item B<license> (type: bool, default: 0)

show license and exit

=item B<copyright> (type: bool, default: 0)

show copyright and exit

=item B<description> (type: bool, default: 0)

show description and exit

=item B<history> (type: bool, default: 0)

show history and exit

=item B<file> (type: devf, default: xmlx/connections/connections.xml)

what input file to use ?

=item B<html> (type: bool, default: 0)

is the input html ?

=back

no free arguments are allowed

=head1 BUGS

None.

=head1 AUTHOR

	Name: Mark Veltzer
	Email: mailto:veltzer@cpan.org
	WWW: http://www.veltzer.org
	CPAN id: VELTZER

=head1 HISTORY

	0.00 MV move tests to modules

=head1 SEE ALSO

HTML::DOMbo(3), HTML::TreeBuilder(3), Meta::Baseline::Aegis(3), Meta::Utils::Opts::Opts(3), Meta::Utils::System(3), XML::DOM(3), strict(3)

=head1 TODO

Nothing.

==> Meta-0.08.tar.gz: Meta-0.08/Meta/Lang/Xml/xml_dom_print.pl <==
#!/usr/bin/env perl

use strict qw(vars refs subs);
use Meta::Utils::System qw();
use Meta::Utils::Opts::Opts qw();
use Meta::Baseline::Aegis qw();
use XML::DOM qw();
use HTML::TreeBuilder qw();
use HTML::DOMbo qw();

my($file,$html);
my($opts)=Meta::Utils::Opts::Opts->new();
$opts->set_standard();
$opts->def_devf("file","what input file to use ?","xmlx/connections/connections.xml",\$file);
$opts->def_bool("html","is the input html ?",0,\$html);
$opts->set_free_allo(0);
$opts->analyze(\@ARGV);

$file=Meta::Baseline::Aegis::which($file);
my($doc);
if($html) {
	my($tree)=HTML::TreeBuilder->new();
	$tree->ignore_ignorable_whitespace(0);
	$tree->no_space_compacting(1);
	$tree->parse_file($file);
	#this is possible because of HTML::DOMbo
	$doc=$tree->to_XML_DOM();
} else {
	my($parser)=XML::DOM::Parser->new();
	$doc=$parser->parsefile($file);
}
print $doc->toString();

Meta::Utils::System::exit_ok();

__END__

=head1 NAME

xml_dom_print.pl - parse an XML using DOM and print the result.

=head1 COPYRIGHT

Copyright (C) 2001, 2002 Mark Veltzer;
All rights reserved.

=head1 LICENSE

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.

=head1 DETAILS

	MANIFEST: xml_dom_print.pl
	PROJECT: meta
	VERSION: 0.01

=head1 SYNOPSIS

	xml_dom_print.pl [options]

=head1 DESCRIPTION

This is a small program which reads an XML document, parses it using
XML::DOM and prints the result. You can use this software to verify
the correctness of an XML document or to see its structure more
clearly.

=head1 OPTIONS

=over 4

=item B<help> (type: bool, default: 0)

display help message

=item B<pod> (type: bool, default: 0)

display pod options snipplet

=item B<man> (type: bool, default: 0)

display manual page

=item B<quit> (type: bool, default: 0)

quit without doing anything

=item B<gtk> (type: bool, default: 0)

run a gtk ui to get the parameters

=item B<license> (type: bool, default: 0)

show license and exit

=item B<copyright> (type: bool, default: 0)

show copyright and exit

=item B<description> (type: bool, default: 0)

show description and exit

=item B<history> (type: bool, default: 0)

show history and exit

=item B<file> (type: devf, default: xmlx/connections/connections.xml)

what input file to use ?

=item B<html> (type: bool, default: 0)

is the input html ?

=back

no free arguments are allowed

=head1 BUGS

None.

=head1 AUTHOR

	Name: Mark Veltzer
	Email: mailto:veltzer@cpan.org
	WWW: http://www.veltzer.org
	CPAN id: VELTZER

=head1 HISTORY

	0.00 MV move tests to modules
	0.01 MV md5 issues

=head1 SEE ALSO

HTML::DOMbo(3), HTML::TreeBuilder(3), Meta::Baseline::Aegis(3), Meta::Utils::Opts::Opts(3), Meta::Utils::System(3), XML::DOM(3), strict(3)

=head1 TODO

Nothing.
